#! /usr/bin/env python3

import os
import sys
import struct

MAX_BOOLCOUNT = 44
MAX_NUMCOUNT = 39
MAX_STRCOUNT = 414

put_short = lambda x: struct.pack("<H", x)
buf = b""

def even_boundary(size):
    if size % 2:
        return b'\x00'
    return b''

TERM_NAME = b"blabla\x00"

MAGIC_16 = 0o432
name_size = len(TERM_NAME)
bool_count = 0x200 # fill a 128B chunk
num_count = 0x20
str_count = MAX_STRCOUNT + 0x200
str_size = 5

buf += put_short(MAGIC_16)
buf += put_short(name_size)
buf += put_short(bool_count)
buf += put_short(num_count)
buf += put_short(str_count)
buf += put_short(str_size)

buf += TERM_NAME
buf += MAX_BOOLCOUNT * b'A' + (bool_count - MAX_BOOLCOUNT) * b"B"
buf += even_boundary(name_size + bool_count)
buf += b"".join(2*bytes([i]) for i in range(num_count))

buf += str_count * put_short(0xfffe)

buf += (str_size-1) * b"Z" + b'\0'

buf += even_boundary(str_size)

# Extended header
#
ext_bool_count = 0x50
ext_num_count = 0x10
ext_str_count = 18
ext_str_size = ext_bool_count + ext_num_count + ext_str_count * 2

ext_str_table = ext_bool_count * b"aaa\0"
ext_str_table += ext_num_count * b"bbb\0"
ext_str_table += ext_str_count * b"ccc\0"
ext_str_table += ext_str_count * b"ddd\0"

ext_str_limit = len(ext_str_table)

buf += put_short(ext_bool_count)
buf += put_short(ext_num_count)
buf += put_short(ext_str_count)
buf += put_short(ext_str_size)
buf += put_short(ext_str_limit)

buf += ext_bool_count * b'C'

buf += even_boundary(ext_bool_count)

buf += b"".join(2*bytes([i+0x60]) for i in range(ext_num_count))

buf += ext_str_size * put_short(0xffff)
buf += ext_str_table

sys.stdout.buffer.write(buf)


